@@ -1,24 +1,9 @@
 <?php
 // +-----------------------------------------------------------------------+
-// | Piwigo - a PHP based photo gallery                                    |
-// +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2016 Piwigo Team                  http://piwigo.org |
-// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
-// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
-// +-----------------------------------------------------------------------+
-// | This program is free software; you can redistribute it and/or modify  |
-// | it under the terms of the GNU General Public License as published by  |
-// | the Free Software Foundation                                          |
+// | This file is part of Piwigo.                                          |
 // |                                                                       |
-// | This program is distributed in the hope that it will be useful, but   |
-// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
-// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
-// | General Public License for more details.                              |
-// |                                                                       |
-// | You should have received a copy of the GNU General Public License     |
-// | along with this program; if not, write to the Free Software           |
-// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
-// | USA.                                                                  |
+// | For copyright and license information, please view the COPYING.txt    |
+// | file that was distributed with this source code.                      |
 // +-----------------------------------------------------------------------+
 
 define('PHPWG_ROOT_PATH','./');
@@ -316,6 +301,7 @@ UPDATE '.CATEGORIES_TABLE.'
   WHERE id = '.$page['category']['id'].'
 ;';
         pwg_query($query);
+        pwg_activity('album', $page['category']['id'], 'edit', array('action'=>$_GET['action'], 'image_id'=>$page['image_id']));
 
         include_once(PHPWG_ROOT_PATH.'admin/include/functions.php');
         invalidate_user_cache();
@@ -444,14 +430,7 @@ else
 // don't increment if adding a comment
 if (trigger_change('allow_increment_element_hit_count', $inc_hit_count, $page['image_id'] ) )
 {
-  // avoiding auto update of "lastmodified" field
-  $query = '
-UPDATE
-  '.IMAGES_TABLE.'
-  SET hit = hit+1, lastmodified = lastmodified
-  WHERE id = '.$page['image_id'].'
-;';
-  pwg_query($query);
+  increase_image_visit_counter($page['image_id']);
 }
 
 //---------------------------------------------------------- related categories
@@ -521,6 +500,10 @@ while ($row = pwg_db_fetch_assoc($result))
   $row['src_image'] = new SrcImage($row);
   $row['derivatives'] = DerivativeImage::get_all($row['src_image']);
 
+  $extTab = explode('.',$row['path']);
+  $row['path_ext'] = strtolower(get_extension($row['path']));
+  $row['file_ext'] = strtolower(get_extension($row['file']));
+
   if ($i=='current')
   {
     $row['element_path'] = get_element_path($row);
@@ -663,7 +646,7 @@ foreach (array('first','previous','next','last', 'current') as $which_image)
       );
   }
 }
-if ($conf['picture_download_icon'] and !empty($picture['current']['download_url']))
+if ($conf['picture_download_icon'] and !empty($picture['current']['download_url']) and $user['enabled_high']=='true')
 {
   $template->append('current', array('U_DOWNLOAD' => $picture['current']['download_url']), true);
 
@@ -988,6 +971,15 @@ SELECT id, name, permalink
   }
 }
 
+if (in_array(strtolower(get_extension($picture['current']['file'])), array('pdf'))) {
+  $template->assign(
+    array(
+      'PDF_VIEWER_FILESIZE_THRESHOLD' => $conf['pdf_viewer_filesize_threshold']*1024,
+      'PDF_NB_PAGES' => count_pdf_pages($picture['current']['path'])
+    )
+  );
+}
+
 // maybe someone wants a special display (call it before page_header so that
 // they can add stylesheets)
 $element_content = trigger_change(
@@ -1054,4 +1046,4 @@ else
 //------------------------------------------------------------ log informations
 pwg_log($picture['current']['id'], 'picture');
 include(PHPWG_ROOT_PATH.'include/page_tail.php');
-?>
\ No newline at end of file
+?>
